#
# spec file for package aquamarine
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   7
%define _description %{expand:
Aquamarine is a very light linux rendering backend library. It
provides basic abstractions for an application to render on a Wayland
session (in a window) or a native DRM session.}
Name:           aquamarine
Version:        0.8.0
Release:        1.1
Summary:        Rendering backend library
License:        BSD-3-Clause
URL:            https://github.com/hyprwm/aquamarine
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  cmake(hyprwayland-scanner) >= 0.4.0
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(hwdata)
BuildRequires:  pkgconfig(hyprutils) >= 0.5.2
BuildRequires:  pkgconfig(libdisplay-info)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libinput) >= 1.26.0
BuildRequires:  pkgconfig(libseat) >= 0.8.0
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols)

%description %{_description}

%package -n lib%{name}%{sover}
Summary:        Rendering backend library
Group:          System/Libraries

%description -n lib%{name}%{sover} %{_description}

%package devel
Summary:        Development package for %{name}
Group:          Development/Languages/C and C++
Requires:       lib%{name}%{sover} = %{version}-%{release}

%description devel %{_description}

This package contains development files necessary to build against
%{name}.

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install

%ldconfig_scriptlets -n lib%{name}%{sover}

%files -n lib%{name}%{sover}
%license LICENSE
%{_libdir}/lib%{name}.so.%{sover}
%{_libdir}/lib%{name}.so.%{version}

%files devel
%doc README.md
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Sun Mar 23 2025 Florian "sp1rit" <sp1rit@disroot.org>
- Update to aquamarine-0.8.0:
  * New major release with various fixes to the infrastructure. ABI
    break.
  * Changes:
  - consolidate EGL init/state
  - Support setting drm content type property
  - Compiler fixes and options
  - drm: only allow multigpu blit to implcit, not all external
    formats
  - prioritize gpus with the most internal panels
  - Get max bpc from drm format
  - fix atomic reset being skipped, check nullptr elsewhere instead
  - drm: Use RAII to manage EGL context
  - Fix multi-GPU support for Nvidia
  - misc: Add strict typing to attachment manager
  - drm: only scan connected connectors
  - backend: Fix Wayland backend idleCallbacks destruction
  - misc: Fix Attachment shared pointer reinterpret
  - backend, allocator: Fix multi-GPU format selection
* Thu Jan 30 2025 Florian "spirit" <sp1rit@disroot.org>
- Update to aquamarine-0.7.2:
  * A minor update with fixes to headless displays in general, with a
    fix to headless buffers and presentation feedback.
  * Fixes:
  - headless/wayland: emit present events after commit
  - fix headless supported formats
  * Other:
  - Core: add clang-tidy
- Changes from aquamarine-0.7.1:
  * A minor update with some small fixes.
  * Fixes:
  - remove wrong property settings
- Changes from aquamarine-0.7.0:
  * Another major release because we broke ABI again.
    From better news, optimization and GPU hotplug infrastructure
    thanks to our wonderful community contributors.
  * Additions:
  - GPU hotplug support
  * Fixes:
  - Avoid excessive atomic properties updates
- Changes from aquamarine-0.6.0:
  * A new major release with various fixes, but also shiny new HDR
    support.
    Please note this release does break ABI.
  * Additions:
  - HDR Support
  * Fixes:
  - udev scan only cards (drm_minor), not connectors
    (drm_connector)
  - drm: moved null check for renderer to shouldBlit()
  - only fail INVALID format when it's set as that
  - only clear buffers when fullReconfigure succeeds
  * Others:
  - log errno set by drmModeAtomicCommit
* Tue Dec 17 2024 Florian "sp1rit" <sp1rit@disroot.org>
- Update to aquamarine-0.5.1:
  * A minor update with some stability improvements.
  * Fixes:
  - buffer: remove useless forward def
  - drm: Validate conn before dereference in
    CDRMAtomicRequest::commit()
  - clearer flow when rescanning connectors
  - allow multigpu blit from explicit to implicit
- Changes from aquamarine-0.5.0:
  * A new major update with a few fixes.
    This update breaks ABI and API compatibility. Sover has been
    bumped to 4.
  * Fixes:
  - Fix fences according to spec
  - scan only cards and not outputs, safeguard against null
    renderer
- Changes from aquamarine-0.4.5:
  * A small update to add a drm_dumb allocator.
* Sat Nov  9 2024 Florian "spirit" <sp1rit@disroot.org>
- Update to aquamarine-0.4.4:
  * drm: guard cursorFB buffer in restoreAfterVT
- Changes from aquamarine-0.4.3:
  * fix drm lease crash
- Changes from aquamarine-0.4.2:
  * A minor update with some fixes and fresh new CTM support.
  * Fixes:
  - session: only dispatch udev in dispatchPendingEventsAsync if on
  linux
  - wayland: log compositor name on startup
* Tue Sep 17 2024 Alessio Biancalana <alessio.biancalana@suse.com>
- Update to aquamarine-0.4.1
  * drm: fix crash on null crtc setCursor
  * gbm: improve trace logging around allocs
  * drm: reconfigure swapchain props after creating
  * output: avoid crashing on no crtc
  * GBM: fixup good() return value
  * drm: verify output format in commit
  * drm: request page flip events after commit
  * drm: add missing destructor
  * drm: fix typo in schedule
  * backend: dont overflow on 32bit builds
  * wayland: fix possible out-of-range crash in setCursor
  * drm: recheck crtcs before connecting on udev event
  * misc: make for loops const reference
  * gbm: improve automatic format selection
  * drm: don't connect before crtcs are guaranteed
  * output: always emit a destroy event in ~dtor
  * gbm/drm: conform to different scanout requirements for different planes
  * wayland: send 1280x720 if w/h is 0 in configure
  * gbm: override gbm_bo_get_modifier results for modifier-based allocation
  * drm: allow disabling commit, even if pageFlipPending
  * drm: add AQ_NO_MODIFIERS to try to mitigate hardware limitations
  * gbm: don't select opaque pixel formats for cursor
- Run spec-cleaner over the specfile
* Thu Aug  8 2024 Florian "sp1rit" <sp1rit@disroot.org>
- Initial packaging of aquamarine-0.3.0
